@@ -943,6 +943,7 @@ _ENUM_BASE_TYPES = (
     ArgumentType.USHORT,
     ArgumentType.INT,
     ArgumentType.UINT,
+    ArgumentType.BOOL,
 )
 
 def _resolve_enums(spec, error_log):
@@ -1933,7 +1934,7 @@ def _search_scope(spec, scope, scoped_name, type):
 
 
 def _name_lookup(spec, mod, scoped_name, type):
-    """ Look up a name and resole the corresponding type. """
+    """ Look up a name and resolve the corresponding type. """
 
     _search_mapped_types(spec, mod, type, scoped_name)
     if type.type is not ArgumentType.NONE:
